Modules
- random
- Patterns that generate random values.
- shapes
- Patterns that generate basic shapes and waves.
- transformers
- Patterns that transform other patterns.
Most transformers should not be used directly, but through methods on the
Patterntrait.
Structs
- Custom
Pattern - Can be used to make simple custom patterns.
- Driver
- Driver that can send patterns to buttplug devices.
Traits
- Pattern
- Extension trait for
PatternGenerator, contains methods for building and transformingPatterns, - Pattern
Generator - Represents a pattern to be used to actuate buttplug devices.