pub struct TriangleWave { /* private fields */ }Expand description
Generates a Triangle wave between 0 and an amplitude for a given duration.
Waves are generated as single pulses with a given wavelength.
To play several cycles of the wave in sequence, use the repeat method.
Implementations