pub struct AmplitudeModulator<P: Pattern, M: Pattern> {
pub pattern: P,
pub modulator: M,
}Expand description
Modulates the amplitude of a pattern by another pattern.
Effectively a multiply combinator.
Fields
pattern: Pmodulator: MTrait Implementations
Sourceimpl<P: Clone + Pattern, M: Clone + Pattern> Clone for AmplitudeModulator<P, M>
impl<P: Clone + Pattern, M: Clone + Pattern> Clone for AmplitudeModulator<P, M>
Sourcefn clone(&self) -> AmplitudeModulator<P, M>
fn clone(&self) -> AmplitudeModulator<P, M>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<P: PartialEq + Pattern, M: PartialEq + Pattern> PartialEq for AmplitudeModulator<P, M>
impl<P: PartialEq + Pattern, M: PartialEq + Pattern> PartialEq for AmplitudeModulator<P, M>
Sourcefn eq(&self, other: &AmplitudeModulator<P, M>) -> bool
fn eq(&self, other: &AmplitudeModulator<P, M>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<P: Pattern, M: Pattern> PatternGenerator for AmplitudeModulator<P, M>
impl<P: Pattern, M: Pattern> PatternGenerator for AmplitudeModulator<P, M>
impl<P: PartialEq + Pattern, M: PartialEq + Pattern> StructuralPartialEq for AmplitudeModulator<P, M>