Skip to main contentCrate buttplug_patterns
Source - random
- Patterns that generate random values.
- shapes
- Patterns that generate basic shapes and waves.
- transformers
- Patterns that transform other patterns.
Most transformers should not be used directly, but through methods on the
Pattern trait.
- CustomPattern
- Can be used to make simple custom patterns.
- Driver
- Driver that can send patterns to buttplug devices.
- Pattern
- Extension trait for
PatternGenerator, contains methods for building and transforming
Patterns, - PatternGenerator
- Represents a pattern to be used to actuate buttplug devices.